@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-from plone.app.linkintegrity.tests.base import ATBaseTestCase
 from plone.app.linkintegrity.tests.base import DXBaseTestCase
 from plone.app.linkintegrity.utils import getIncomingLinks
 from plone.app.linkintegrity.utils import getOutgoingLinks
 from plone.uuid.interfaces import IUUID
 
+import six
+
 
 class ImageReferenceTestCase:
 
@@ -65,6 +66,8 @@ class ImageReferenceTestCase:
 class ImageReferenceDXTestCase(DXBaseTestCase, ImageReferenceTestCase):
     """Image reference testcase for dx content types"""
 
+if six.PY2:
+    from plone.app.linkintegrity.tests.base import ATBaseTestCase
 
-class ImageReferenceATTestCase(ATBaseTestCase, ImageReferenceTestCase):
-    """Image reference testcase for dx content types"""
+    class ImageReferenceATTestCase(ATBaseTestCase, ImageReferenceTestCase):
+        """Image reference testcase for dx content types"""
